summaryrefslogtreecommitdiffstats
path: root/src/widgets
diff options
context:
space:
mode:
Diffstat (limited to 'src/widgets')
-rw-r--r--src/widgets/qaction.cpp12
-rw-r--r--src/widgets/qbutton.cpp2
-rw-r--r--src/widgets/qcombobox.cpp4
-rw-r--r--src/widgets/qdatetimeedit.cpp4
-rw-r--r--src/widgets/qdialogbuttons.cpp4
-rw-r--r--src/widgets/qdockarea.cpp22
-rw-r--r--src/widgets/qheader.cpp2
-rw-r--r--src/widgets/qlcdnumber.cpp8
-rw-r--r--src/widgets/qlistbox.cpp12
-rw-r--r--src/widgets/qlistview.cpp18
-rw-r--r--src/widgets/qmenudata.cpp2
-rw-r--r--src/widgets/qpopupmenu.cpp4
-rw-r--r--src/widgets/qrangecontrol.cpp2
-rw-r--r--src/widgets/qscrollview.cpp4
-rw-r--r--src/widgets/qslider.cpp2
-rw-r--r--src/widgets/qstatusbar.cpp4
-rw-r--r--src/widgets/qtextbrowser.cpp4
-rw-r--r--src/widgets/qtextedit.cpp10
-rw-r--r--src/widgets/qtoolbutton.cpp6
-rw-r--r--src/widgets/qwhatsthis.cpp4
20 files changed, 65 insertions, 65 deletions
diff --git a/src/widgets/qaction.cpp b/src/widgets/qaction.cpp
index 7db8c1e..1e68de0 100644
--- a/src/widgets/qaction.cpp
+++ b/src/widgets/qaction.cpp
@@ -785,7 +785,7 @@ void QAction::setAccel( const QKeySequence& key )
}
#if defined(QT_CHECK_STATE)
else
- tqWarning( "QAction::setAccel() (%s) requires widget in parent chain", name() );
+ qWarning( "QAction::setAccel() (%s) requires widget in parent chain", name() );
#endif
d->update();
}
@@ -841,7 +841,7 @@ void QAction::activate()
{
if ( isToggleAction() ) {
#if defined(QT_CHECK_STATE)
- tqWarning( "QAction::%s() (%s) Toggle actions "
+ qWarning( "QAction::%s() (%s) Toggle actions "
"can not be activated", "activate", name() );
#endif
return;
@@ -858,7 +858,7 @@ void QAction::toggle()
{
if ( !isToggleAction() ) {
#if defined(QT_CHECK_STATE)
- tqWarning( "QAction::%s() (%s) Only toggle actions "
+ qWarning( "QAction::%s() (%s) Only toggle actions "
"can be switched", "toggle", name() );
#endif
return;
@@ -882,7 +882,7 @@ void QAction::setOn( bool enable )
if ( !isToggleAction() ) {
#if defined(QT_CHECK_STATE)
if ( enable )
- tqWarning( "QAction::%s() (%s) Only toggle actions "
+ qWarning( "QAction::%s() (%s) Only toggle actions "
"can be switched", "setOn", name() );
#endif
return;
@@ -1066,7 +1066,7 @@ bool QAction::addTo( QWidget* w )
d->update( QActionPrivate::State | QActionPrivate::EverythingElse );
} else {
- tqWarning( "QAction::addTo(), unknown object" );
+ qWarning( "QAction::addTo(), unknown object" );
return FALSE;
}
return TRUE;
@@ -1226,7 +1226,7 @@ bool QAction::removeFrom( QWidget* w )
}
}
} else {
- tqWarning( "QAction::removeFrom(), unknown object" );
+ qWarning( "QAction::removeFrom(), unknown object" );
return FALSE;
}
return TRUE;
diff --git a/src/widgets/qbutton.cpp b/src/widgets/qbutton.cpp
index 1395169..57178fb 100644
--- a/src/widgets/qbutton.cpp
+++ b/src/widgets/qbutton.cpp
@@ -631,7 +631,7 @@ void QButton::setState( ToggleState s )
{
if ( !toggleTyp ) {
#if defined(QT_CHECK_STATE)
- tqWarning( "QButton::setState() / setOn: (%s) Only toggle buttons "
+ qWarning( "QButton::setState() / setOn: (%s) Only toggle buttons "
"may be switched", name( "unnamed" ) );
#endif
return;
diff --git a/src/widgets/qcombobox.cpp b/src/widgets/qcombobox.cpp
index 39788b1..1da559c 100644
--- a/src/widgets/qcombobox.cpp
+++ b/src/widgets/qcombobox.cpp
@@ -469,7 +469,7 @@ static inline bool checkInsertIndex( const char *method, const char * name,
bool range_err = (*index > count);
#if defined(QT_CHECK_RANGE)
if ( range_err )
- tqWarning( "QComboBox::%s: (%s) Index %d out of range",
+ qWarning( "QComboBox::%s: (%s) Index %d out of range",
method, name ? name : "<no name>", *index );
#else
Q_UNUSED( method )
@@ -487,7 +487,7 @@ static inline bool checkIndex( const char *method, const char * name,
bool range_err = (index >= count);
#if defined(QT_CHECK_RANGE)
if ( range_err )
- tqWarning( "QComboBox::%s: (%s) Index %i out of range",
+ qWarning( "QComboBox::%s: (%s) Index %i out of range",
method, name ? name : "<no name>", index );
#else
Q_UNUSED( method )
diff --git a/src/widgets/qdatetimeedit.cpp b/src/widgets/qdatetimeedit.cpp
index 9ac3afb..6f6ca71 100644
--- a/src/widgets/qdatetimeedit.cpp
+++ b/src/widgets/qdatetimeedit.cpp
@@ -2118,7 +2118,7 @@ void QTimeEdit::stepUp()
default:
accepted = FALSE;
#ifdef QT_CHECK_RANGE
- tqWarning( "QTimeEdit::stepUp: Focus section out of range!" );
+ qWarning( "QTimeEdit::stepUp: Focus section out of range!" );
#endif
break;
}
@@ -2170,7 +2170,7 @@ void QTimeEdit::stepDown()
default:
accepted = FALSE;
#ifdef QT_CHECK_RANGE
- tqWarning( "QTimeEdit::stepDown: Focus section out of range!" );
+ qWarning( "QTimeEdit::stepDown: Focus section out of range!" );
#endif
break;
}
diff --git a/src/widgets/qdialogbuttons.cpp b/src/widgets/qdialogbuttons.cpp
index b6dcbae..787a406 100644
--- a/src/widgets/qdialogbuttons.cpp
+++ b/src/widgets/qdialogbuttons.cpp
@@ -84,7 +84,7 @@ void
QDialogButtons::init(Q_UINT32 buttons, Orientation orient)
{
if(buttons == All) {
- tqWarning("QDialogButtons: cannot specify All by itself!");
+ qWarning("QDialogButtons: cannot specify All by itself!");
buttons = None;
}
d = new QDialogButtonsPrivate;
@@ -173,7 +173,7 @@ void
QDialogButtons::setDefaultButton(Button button)
{
if(!((int)(d->visible & button) == button)) {
- tqWarning("QDialogButtons: Button '%d' is not visible (so cannot be default)", button);
+ qWarning("QDialogButtons: Button '%d' is not visible (so cannot be default)", button);
return;
}
if(d->def != button) {
diff --git a/src/widgets/qdockarea.cpp b/src/widgets/qdockarea.cpp
index 375730f..2d4d957 100644
--- a/src/widgets/qdockarea.cpp
+++ b/src/widgets/qdockarea.cpp
@@ -766,21 +766,21 @@ void QDockArea::moveDockWindow( QDockWindow *w, const QPoint &p, const QRect &r,
insertLine = TRUE;
#if defined(QDOCKAREA_DEBUG)
- tqDebug( "insert in line %d, and insert that line: %d", dockLine, insertLine );
- tqDebug( " (btw, we have %d lines)", lines.count() );
+ qDebug( "insert in line %d, and insert that line: %d", dockLine, insertLine );
+ qDebug( " (btw, we have %d lines)", lines.count() );
#endif
QDockWindow *dw = 0;
if ( dockLine >= (int)lines.count() ) { // insert after last line
dockWindows->append( dockWindow );
dockWindow->setNewLine( TRUE );
#if defined(QDOCKAREA_DEBUG)
- tqDebug( "insert at the end" );
+ qDebug( "insert at the end" );
#endif
} else if ( dockLine == 0 && insertLine ) { // insert before first line
dockWindows->insert( 0, dockWindow );
dockWindows->at( 1 )->setNewLine( TRUE );
#if defined(QDOCKAREA_DEBUG)
- tqDebug( "insert at the begin" );
+ qDebug( "insert at the begin" );
#endif
} else { // insert somewhere in between
// make sure each line start has a new line
@@ -790,7 +790,7 @@ void QDockArea::moveDockWindow( QDockWindow *w, const QPoint &p, const QRect &r,
// find the index of the first widget in the search line
int searchLine = dockLine;
#if defined(QDOCKAREA_DEBUG)
- tqDebug( "search line start of %d", searchLine );
+ qDebug( "search line start of %d", searchLine );
#endif
QDockWindow *lsw = lineStarts.at( searchLine );
int index = dockWindows->find( lsw );
@@ -803,7 +803,7 @@ void QDockArea::moveDockWindow( QDockWindow *w, const QPoint &p, const QRect &r,
(void)dockWindows->at( index ); // move current to index
}
#if defined(QDOCKAREA_DEBUG)
- tqDebug( " which starts at %d", index );
+ qDebug( " which starts at %d", index );
#endif
if ( !insertLine ) { // if we insert the docking widget in the existing line
// find the index for the widget
@@ -825,7 +825,7 @@ void QDockArea::moveDockWindow( QDockWindow *w, const QPoint &p, const QRect &r,
firstTime = FALSE;
}
#if defined(QDOCKAREA_DEBUG)
- tqDebug( "insert at index: %d", index );
+ qDebug( "insert at index: %d", index );
#endif
// if we insert it just before a widget which has a new line, transfer the newline to the docking widget
// but not if we didn't only mave a widget in its line which was alone in the line before
@@ -833,7 +833,7 @@ void QDockArea::moveDockWindow( QDockWindow *w, const QPoint &p, const QRect &r,
&& index >= 0 && index < (int)dockWindows->count() &&
dockWindows->at( index )->newLine() && lineOf( index ) == dockLine ) {
#if defined(QDOCKAREA_DEBUG)
- tqDebug( "get rid of the old newline and get me one" );
+ qDebug( "get rid of the old newline and get me one" );
#endif
dockWindows->at( index )->setNewLine( FALSE );
dockWindow->setNewLine( TRUE );
@@ -844,18 +844,18 @@ void QDockArea::moveDockWindow( QDockWindow *w, const QPoint &p, const QRect &r,
}
} else { // insert in a new line, so make sure the dock widget and the widget which will be after it have a newline
#if defined(QDOCKAREA_DEBUG)
- tqDebug( "insert a new line" );
+ qDebug( "insert a new line" );
#endif
if ( index < (int)dockWindows->count() ) {
#if defined(QDOCKAREA_DEBUG)
- tqDebug( "give the widget at %d a newline", index );
+ qDebug( "give the widget at %d a newline", index );
#endif
QDockWindow* nldw = dockWindows->at( index );
if ( nldw )
nldw->setNewLine( TRUE );
}
#if defined(QDOCKAREA_DEBUG)
- tqDebug( "give me a newline" );
+ qDebug( "give me a newline" );
#endif
dockWindow->setNewLine( TRUE );
}
diff --git a/src/widgets/qheader.cpp b/src/widgets/qheader.cpp
index e12f25d..82fd012 100644
--- a/src/widgets/qheader.cpp
+++ b/src/widgets/qheader.cpp
@@ -826,7 +826,7 @@ void QHeader::mouseMoveEvent( QMouseEvent *e )
break;
}
default:
- tqWarning( "QHeader::mouseMoveEvent: (%s) unknown state", name() );
+ qWarning( "QHeader::mouseMoveEvent: (%s) unknown state", name() );
break;
}
}
diff --git a/src/widgets/qlcdnumber.cpp b/src/widgets/qlcdnumber.cpp
index 2358dbe..4398907 100644
--- a/src/widgets/qlcdnumber.cpp
+++ b/src/widgets/qlcdnumber.cpp
@@ -375,14 +375,14 @@ void QLCDNumber::setNumDigits( int numDigits )
{
if ( numDigits > 99 ) {
#if defined(QT_CHECK_RANGE)
- tqWarning( "QLCDNumber::setNumDigits: (%s) Max 99 digits allowed",
+ qWarning( "QLCDNumber::setNumDigits: (%s) Max 99 digits allowed",
name( "unnamed" ) );
#endif
numDigits = 99;
}
if (numDigits < 0 ) {
#if defined(QT_CHECK_RANGE)
- tqWarning( "QLCDNumber::setNumDigits: (%s) Min 0 digits allowed",
+ qWarning( "QLCDNumber::setNumDigits: (%s) Min 0 digits allowed",
name( "unnamed" ) );
#endif
numDigits = 0;
@@ -976,7 +976,7 @@ void QLCDNumber::drawSegment( const QPoint &pos, char segmentNo, QPainter &p,
break;
#if defined(QT_CHECK_RANGE)
default :
- tqWarning( "QLCDNumber::drawSegment: (%s) Internal error."
+ qWarning( "QLCDNumber::drawSegment: (%s) Internal error."
" Illegal segment id: %d\n",
name( "unnamed" ), segmentNo );
#endif
@@ -1111,7 +1111,7 @@ void QLCDNumber::drawSegment( const QPoint &pos, char segmentNo, QPainter &p,
break;
#if defined(QT_CHECK_RANGE)
default :
- tqWarning( "QLCDNumber::drawSegment: (%s) Internal error."
+ qWarning( "QLCDNumber::drawSegment: (%s) Internal error."
" Illegal segment id: %d\n",
name( "unnamed" ), segmentNo );
#endif
diff --git a/src/widgets/qlistbox.cpp b/src/widgets/qlistbox.cpp
index 18968e9..f5e0057 100644
--- a/src/widgets/qlistbox.cpp
+++ b/src/widgets/qlistbox.cpp
@@ -3789,14 +3789,14 @@ void QListBox::viewportPaintEvent( QPaintEvent * e )
// this stuff has been useful enough times that from now I'm
// leaving it in the source.
uint i = 0;
- tqDebug( "%s/%s: %i rects", className(), name(), r.rects().size() );
+ qDebug( "%s/%s: %i rects", className(), name(), r.rects().size() );
while( i < r.rects().size() ) {
- tqDebug( "rect %d: %d, %d, %d, %d", i,
+ qDebug( "rect %d: %d, %d, %d, %d", i,
r.rects()[i].left(), r.rects()[i].top(),
r.rects()[i].width(), r.rects()[i].height() );
i++;
}
- tqDebug( "" );
+ qDebug( "" );
}
#endif
@@ -3977,7 +3977,7 @@ QRect QListBox::itemRect( QListBoxItem *item ) const
*/
int QListBox::inSort( const QListBoxItem * lbi )
{
- tqObsolete( "QListBox", "inSort", "insertItem" );
+ qObsolete( "QListBox", "inSort", "insertItem" );
if ( !lbi )
return -1;
@@ -4009,7 +4009,7 @@ int QListBox::inSort( const QListBoxItem * lbi )
*/
int QListBox::inSort( const QString& text )
{
- tqObsolete( "QListBox", "inSort", "insertItem" );
+ qObsolete( "QListBox", "inSort", "insertItem" );
return inSort( new QListBoxText(text) );
}
@@ -4160,7 +4160,7 @@ void QListBox::showEvent( QShowEvent * )
*/
bool QListBox::itemYPos( int index, int *yPos ) const
{
- tqObsolete( "QListBox", "itemYPos" );
+ qObsolete( "QListBox", "itemYPos" );
QListBoxItem* i = item(index);
if ( !i )
return FALSE;
diff --git a/src/widgets/qlistview.cpp b/src/widgets/qlistview.cpp
index 0fe6818..d441a59 100644
--- a/src/widgets/qlistview.cpp
+++ b/src/widgets/qlistview.cpp
@@ -6048,7 +6048,7 @@ QCheckListItem::QCheckListItem( QCheckListItem *parent, const QString &text,
init();
if ( myType == RadioButton ) {
if ( parent->type() != RadioButtonController )
- tqWarning( "QCheckListItem::QCheckListItem(), radio button must be "
+ qWarning( "QCheckListItem::QCheckListItem(), radio button must be "
"child of a controller" );
else
d->exclusive = parent;
@@ -6069,7 +6069,7 @@ QCheckListItem::QCheckListItem( QCheckListItem *parent, QListViewItem *after,
init();
if ( myType == RadioButton ) {
if ( parent->type() != RadioButtonController )
- tqWarning( "QCheckListItem::QCheckListItem(), radio button must be "
+ qWarning( "QCheckListItem::QCheckListItem(), radio button must be "
"child of a controller" );
else
d->exclusive = parent;
@@ -6088,7 +6088,7 @@ QCheckListItem::QCheckListItem( QListViewItem *parent, const QString &text,
{
myType = tt;
if ( myType == RadioButton ) {
- tqWarning( "QCheckListItem::QCheckListItem(), radio button must be "
+ qWarning( "QCheckListItem::QCheckListItem(), radio button must be "
"child of a QCheckListItem" );
}
init();
@@ -6107,7 +6107,7 @@ QCheckListItem::QCheckListItem( QListViewItem *parent, QListViewItem *after,
{
myType = tt;
if ( myType == RadioButton ) {
- tqWarning( "QCheckListItem::QCheckListItem(), radio button must be "
+ qWarning( "QCheckListItem::QCheckListItem(), radio button must be "
"child of a QCheckListItem" );
}
init();
@@ -6125,7 +6125,7 @@ QCheckListItem::QCheckListItem( QListView *parent, const QString &text,
{
myType = tt;
if ( tt == RadioButton )
- tqWarning( "QCheckListItem::QCheckListItem(), radio button must be "
+ qWarning( "QCheckListItem::QCheckListItem(), radio button must be "
"child of a QCheckListItem" );
init();
}
@@ -6142,7 +6142,7 @@ QCheckListItem::QCheckListItem( QListView *parent, QListViewItem *after,
{
myType = tt;
if ( tt == RadioButton )
- tqWarning( "QCheckListItem::QCheckListItem(), radio button must be "
+ qWarning( "QCheckListItem::QCheckListItem(), radio button must be "
"child of a QCheckListItem" );
init();
}
@@ -6236,7 +6236,7 @@ QCheckListItem::~QCheckListItem()
void QCheckListItem::setTristate( bool b )
{
if ( ( myType != CheckBoxController ) && ( myType != CheckBox ) ) {
- tqWarning( "QCheckListItem::setTristate(), has no effect on RadioButton "
+ qWarning( "QCheckListItem::setTristate(), has no effect on RadioButton "
"or RadioButtonController." );
return;
}
@@ -7733,7 +7733,7 @@ QListViewItemIterator &QListViewItemIterator::operator-=( int j )
QListViewItem* QListViewItemIterator::operator*()
{
if ( curr != 0 && !matchesFlags( curr ) )
- tqWarning( "QListViewItemIterator::operator*() curr out of sync" );
+ qWarning( "QListViewItemIterator::operator*() curr out of sync" );
return curr;
}
@@ -7744,7 +7744,7 @@ QListViewItem* QListViewItemIterator::operator*()
QListViewItem *QListViewItemIterator::current() const
{
if ( curr != 0 && !matchesFlags( curr ) )
- tqWarning( "QListViewItemIterator::current() curr out of sync" );
+ qWarning( "QListViewItemIterator::current() curr out of sync" );
return curr;
}
diff --git a/src/widgets/qmenudata.cpp b/src/widgets/qmenudata.cpp
index a5ade29..518ea6b 100644
--- a/src/widgets/qmenudata.cpp
+++ b/src/widgets/qmenudata.cpp
@@ -813,7 +813,7 @@ void QMenuData::removeItemAt( int index )
{
if ( index < 0 || index >= (int)mitems->count() ) {
#if defined(QT_CHECK_RANGE)
- tqWarning( "QMenuData::removeItem: Index %d out of range", index );
+ qWarning( "QMenuData::removeItem: Index %d out of range", index );
#endif
return;
}
diff --git a/src/widgets/qpopupmenu.cpp b/src/widgets/qpopupmenu.cpp
index a2d7446..9e1e01c 100644
--- a/src/widgets/qpopupmenu.cpp
+++ b/src/widgets/qpopupmenu.cpp
@@ -112,7 +112,7 @@ static void cleanup()
static void popupSubMenuLater( int msec, QPopupMenu * receiver ) {
if ( !singleSingleShot ) {
singleSingleShot = new QTimer( qApp, "popup submenu timer" );
- tqAddPostRoutine( cleanup );
+ qAddPostRoutine( cleanup );
}
singleSingleShot->disconnect( SIGNAL(timeout()) );
@@ -1163,7 +1163,7 @@ QSize QPopupMenu::updateSize(bool force_update, bool do_resize)
#if defined(QT_CHECK_NULL)
if ( mi->text().isNull() && !mi->pixmap() && !mi->iconSet() &&
!mi->isSeparator() && !mi->widget() && !mi->custom() )
- tqWarning( "QPopupMenu: (%s) Popup has invalid menu item",
+ qWarning( "QPopupMenu: (%s) Popup has invalid menu item",
name( "unnamed" ) );
#endif
}
diff --git a/src/widgets/qrangecontrol.cpp b/src/widgets/qrangecontrol.cpp
index e9b325f..c329831 100644
--- a/src/widgets/qrangecontrol.cpp
+++ b/src/widgets/qrangecontrol.cpp
@@ -348,7 +348,7 @@ void QRangeControl::setRange( int minValue, int maxValue )
{
if ( minValue > maxValue ) {
#if defined(QT_CHECK_RANGE)
- tqWarning( "QRangeControl::setRange: minValue %d > maxValue %d",
+ qWarning( "QRangeControl::setRange: minValue %d > maxValue %d",
minValue, maxValue );
#endif
maxValue = minValue;
diff --git a/src/widgets/qscrollview.cpp b/src/widgets/qscrollview.cpp
index aa9651e..6af8f12 100644
--- a/src/widgets/qscrollview.cpp
+++ b/src/widgets/qscrollview.cpp
@@ -1388,7 +1388,7 @@ void QScrollView::addChild(QWidget* child, int x, int y)
{
if ( !child ) {
#if defined(QT_CHECK_NULL)
- tqWarning( "QScrollView::addChild(): Cannot add null child" );
+ qWarning( "QScrollView::addChild(): Cannot add null child" );
#endif
return;
}
@@ -2589,7 +2589,7 @@ void QScrollView::enableClipper(bool y)
if ( !d->clipped_viewport == !y )
return;
if ( d->children.count() )
- tqFatal("May only call QScrollView::enableClipper() before adding widgets");
+ qFatal("May only call QScrollView::enableClipper() before adding widgets");
if ( y ) {
d->clipped_viewport = new QClipperWidget(clipper(), "qt_clipped_viewport", d->flags);
d->clipped_viewport->setGeometry(-coord_limit/2,-coord_limit/2,
diff --git a/src/widgets/qslider.cpp b/src/widgets/qslider.cpp
index d10a444..1573294 100644
--- a/src/widgets/qslider.cpp
+++ b/src/widgets/qslider.cpp
@@ -601,7 +601,7 @@ void QSlider::resetState()
case Idle:
break;
default:
- tqWarning("QSlider: (%s) in wrong state", name( "unnamed" ) );
+ qWarning("QSlider: (%s) in wrong state", name( "unnamed" ) );
}
state = Idle;
}
diff --git a/src/widgets/qstatusbar.cpp b/src/widgets/qstatusbar.cpp
index 1a66fba..9a57704 100644
--- a/src/widgets/qstatusbar.cpp
+++ b/src/widgets/qstatusbar.cpp
@@ -194,7 +194,7 @@ void QStatusBar::addWidget( QWidget * widget, int stretch, bool permanent )
{
if ( !widget ) {
#if defined(QT_CHECK_NULL)
- tqWarning( "QStatusBar::addWidget(): Cannot add null widget" );
+ qWarning( "QStatusBar::addWidget(): Cannot add null widget" );
#endif
return;
}
@@ -246,7 +246,7 @@ void QStatusBar::removeWidget( QWidget* widget )
reformat();
#if defined(QT_DEBUG)
else
- tqDebug( "QStatusBar::removeWidget(): Widget not found." );
+ qDebug( "QStatusBar::removeWidget(): Widget not found." );
#endif
}
diff --git a/src/widgets/qtextbrowser.cpp b/src/widgets/qtextbrowser.cpp
index 7824de6..38e280b 100644
--- a/src/widgets/qtextbrowser.cpp
+++ b/src/widgets/qtextbrowser.cpp
@@ -251,11 +251,11 @@ void QTextBrowser::setSource(const QString& name)
const QMimeSource* m =
mimeSourceFactory()->data( source, context() );
if ( !m ){
- tqWarning("QTextBrowser: no mimesource for %s", source.latin1() );
+ qWarning("QTextBrowser: no mimesource for %s", source.latin1() );
}
else {
if ( !QTextDrag::decode( m, txt ) ) {
- tqWarning("QTextBrowser: cannot decode %s", source.latin1() );
+ qWarning("QTextBrowser: cannot decode %s", source.latin1() );
}
}
if ( isVisible() ) {
diff --git a/src/widgets/qwhatsthis.cpp b/src/widgets/qwhatsthis.cpp
index 9a57c44..c6e8f04 100644
--- a/src/widgets/qwhatsthis.cpp
+++ b/src/widgets/qwhatsthis.cpp
@@ -417,7 +417,7 @@ void QWhatsThat::paintEvent( QPaintEvent* )
QWhatsThisPrivate::WhatsThisItem::~WhatsThisItem()
{
if ( count )
- tqFatal( "QWhatsThis: Internal error (%d)", count );
+ qFatal( "QWhatsThis: Internal error (%d)", count );
delete whatsthis;
}
@@ -617,7 +617,7 @@ void QWhatsThisPrivate::setUpWhatsThis()
// It is necessary to use a post routine, because
// the destructor deletes pixmaps and other stuff that
// needs a working X connection under X11.
- tqAddPostRoutine( qWhatsThisPrivateCleanup );
+ qAddPostRoutine( qWhatsThisPrivateCleanup );
}
}
diff --git a/src/widgets/qtextedit.cpp b/src/widgets/qtextedit.cpp
index e305d14..0908e84 100644
--- a/src/widgets/qtextedit.cpp
+++ b/src/widgets/qtextedit.cpp
@@ -5069,7 +5069,7 @@ void QTextEdit::updateStyles()
void QTextEdit::setDocument( QTextDocument *dc )
{
if ( dc == 0 ) {
- tqWarning( "Q3TextEdit::setDocument() called with null Q3TextDocument pointer" );
+ qWarning( "Q3TextEdit::setDocument() called with null Q3TextDocument pointer" );
return;
}
if ( dc == doc )
@@ -6452,7 +6452,7 @@ void QTextEdit::optimParseTags( QString * line, int lineNo, int indexOffset )
cur = tag->prev;
if ( !cur ) {
#ifdef QT_CHECK_RANGE
- tqWarning( "QTextEdit::optimParseTags: no left-tag for '<%s>' in line %d.", tag->tag.ascii(), tag->line + 1 );
+ qWarning( "QTextEdit::optimParseTags: no left-tag for '<%s>' in line %d.", tag->tag.ascii(), tag->line + 1 );
#endif
return; // something is wrong - give up
}
@@ -6475,7 +6475,7 @@ void QTextEdit::optimParseTags( QString * line, int lineNo, int indexOffset )
break;
} else if ( !cur->leftTag ) {
#ifdef QT_CHECK_RANGE
- tqWarning( "QTextEdit::optimParseTags: mismatching %s-tag for '<%s>' in line %d.", cur->tag[0] == '/' ? "left" : "right", cur->tag.ascii(), cur->line + 1 );
+ qWarning( "QTextEdit::optimParseTags: mismatching %s-tag for '<%s>' in line %d.", cur->tag[0] == '/' ? "left" : "right", cur->tag.ascii(), cur->line + 1 );
#endif
return; // something is amiss - give up
}
@@ -6956,9 +6956,9 @@ void QTextEdit::optimDrawContents( QPainter * p, int clipx, int clipy,
// useful debug info
//
// tag = d->od->tags;
-// tqWarning("###");
+// qWarning("###");
// while ( tag ) {
// tqWarning( "Tag: %p, parent: %09p, leftTag: %09p, Name: %-15s, ParentName: %s, %d%d%d", tag,
// tag->parent, tag->leftTag, tag->tag.latin1(), tag->parent ? tag->parent->tag.latin1():"<none>",
// tag->bold, tag->italic, tag->underline );
// tag = tag->next;
@@ -6956,9 +6956,9 @@ void QTextEdit::optimDrawContents( QPainter * p, int clipx, int clipy,
// while ( tag ) {
-// tqWarning( "Tag: %p, parent: %09p, leftTag: %09p, Name: %-15s, ParentName: %s, %d%d%d", tag,
+// qWarning( "Tag: %p, parent: %09p, leftTag: %09p, Name: %-15s, ParentName: %s, %d%d%d", tag,
// tag->parent, tag->leftTag, tag->tag.latin1(), tag->parent ? tag->parent->tag.latin1():"<none>",
// tag->bold, tag->italic, tag->underline );
diff --git a/src/widgets/qtoolbutton.cpp b/src/widgets/qtoolbutton.cpp
index 2f1b59b..f11b613 100644
--- a/src/widgets/qtoolbutton.cpp
+++ b/src/widgets/qtoolbutton.cpp
@@ -716,10 +716,10 @@ void QToolButton::setOnIconSet( const QIconSet& set )
{
setIconSet( set );
/*
### Get rid of all tqWarning in this file in 4.0.
Also consider inlining the obsolete functions then.
*/
- tqWarning( "QToolButton::setOnIconSet(): This function is not supported"
+ qWarning( "QToolButton::setOnIconSet(): This function is not supported"
" anymore" );
}
@@ -790,7 +790,7 @@ void QToolButton::setIconSet( const QIconSet & set )
void QToolButton::setIconSet( const QIconSet & set, bool /* on */ )
{
setIconSet( set );
- tqWarning( "QToolButton::setIconSet(): 'on' parameter ignored" );
+ qWarning( "QToolButton::setIconSet(): 'on' parameter ignored" );
}
#endif
@@ -716,10 +716,10 @@ void QToolButton::setOnIconSet( const QIconSet& set )
setIconSet( set );
/*
- ### Get rid of all tqWarning in this file in 4.0.
+ ### Get rid of all qWarning in this file in 4.0.
Also consider inlining the obsolete functions then.
*/